@@ -1,5 +1,5 @@
 makeAlgorithm = function(id, fun) {
-  setClasses(list(id=id, fun=fun), "Algorithm")
+  setClasses(list(id = id, fun = fun), "Algorithm")
 }
 
 #' Add an algorithm to registry.
@@ -26,31 +26,29 @@ makeAlgorithm = function(id, fun) {
 #' @return [\code{character(1)}]. Invisibly returns the id.
 #' @aliases Algorithm
 #' @export
-addAlgorithm = function(reg, id, fun, overwrite=FALSE)  {
-  checkExperimentRegistry(reg, strict=TRUE)
-  checkArg(id, cl = "character", len=1L, na.ok=FALSE)
+addAlgorithm = function(reg, id, fun, overwrite = FALSE)  {
+  checkExperimentRegistry(reg, strict = TRUE)
   BatchJobs:::checkIdValid(id)
-  checkArg(overwrite, "logical", len=1L, na.ok=FALSE)
+  assertFlag(overwrite)
 
   if (id %in% dbGetAllProblemIds(reg))
     stopf("Problem with same id as your algorithm already exists: %s", id)
   if (!overwrite && id %in% dbGetAllAlgorithmIds(reg))
-    stopf("Algorithm with same id already exists and overwrite=FALSE: %s", id)
+    stopf("Algorithm with same id already exists and overwrite = FALSE: %s", id)
 
   algorithm = makeAlgorithm(id, fun)
   fn = getAlgorithmFilePath(reg$file.dir, id)
-  message("Writing algorithm file: ", fn)
-  save(file=fn, algorithm)
+  info("Writing algorithm file: %s", fn)
+  save(file = fn, algorithm)
   dbAddAlgorithm(reg, id)
   invisible(id)
 }
 
-#' @S3method print Algorithm
+#' @export
 print.Algorithm = function(x, ...) {
   cat("Algorithm:", x$id, "\n")
 }
 
-loadAlgorithm = function(file.dir, id) {
-  fn = getAlgorithmFilePath(file.dir, id)
-  load2(fn, "algorithm")
+loadAlgorithm = function(reg, id) {
+  load2(getAlgorithmFilePath(reg$file.dir, id), "algorithm")
 }
