@@ -7,10 +7,10 @@
 #' @return [\code{\link{Algorithm}}].
 #' @export
 getAlgorithm = function(reg, id) {
-  checkExperimentRegistry(reg, strict=TRUE)
-  checkArg(id, "character", na.ok=FALSE, len=1L)
+  checkExperimentRegistry(reg, strict = TRUE)
+  assertString(id, "character")
   aids = dbGetAllAlgorithmIds(reg)
   if (id %nin% aids)
     stop("Unknown algorithm id, possible candidates are: ", collapse(aids))
-  loadAlgorithm(reg$file.dir, id)
+  loadAlgorithm(reg, id)
 }
