@@ -29,14 +29,14 @@
 #'   Default is \code{default.stringsAsFactors()}.
 #' @return [\code{data.frame}]. Aggregated results, containing problem and algorithm paramaters and collected values.
 #' @export
-reduceResultsExperimentsParallel = function(reg, ids, part=as.character(NA), fun, ..., njobs=20L, strings.as.factors=default.stringsAsFactors()) {
-  checkExperimentRegistry(reg, strict=TRUE)
+reduceResultsExperimentsParallel = function(reg, ids, part = as.character(NA), fun, ..., njobs = 20L, strings.as.factors = default.stringsAsFactors()) {
+  checkExperimentRegistry(reg, strict = TRUE)
   BatchJobs:::syncRegistry(reg)
   if (missing(ids)) {
     ids = BatchJobs:::dbFindDone(reg)
   } else {
     ids = BatchJobs:::checkIds(reg, ids)
-    ndone = BatchJobs:::dbFindDone(reg, ids, negate=TRUE)
+    ndone = BatchJobs:::dbFindDone(reg, ids, negate = TRUE)
     if (length(ndone) > 0L)
       stopf("No results available for experiments with ids: %s", collapse(ndone))
   }
@@ -45,11 +45,10 @@ reduceResultsExperimentsParallel = function(reg, ids, part=as.character(NA), fun
     fun = function(job, res) res
   } else {
     fun = match.fun(fun)
-    checkArg(fun, formals=c("job", "res"))
+    assertFunction(fun, c("job", "res"))
   }
-  njobs = convertInteger(njobs)
-  checkArg(njobs, "integer", len=1L, na.ok=FALSE)
-  checkArg(strings.as.factors, "logical", len=1L, na.ok=FALSE)
+  njobs = asCount(njobs, positive = TRUE)
+  assertFlag(strings.as.factors)
 
   n = length(ids)
   if (n == 0) {
@@ -59,21 +58,21 @@ reduceResultsExperimentsParallel = function(reg, ids, part=as.character(NA), fun
     return(addClasses(res, "ReducedResultsExperiments"))
   }
 
-  messagef("Reducing %i results...", n)
+  info("Reducing %i results...", n)
 
-  ch = chunk(ids, n.chunks=njobs, shuffle=FALSE)
-  more.args = c(list(reg=reg, part=part, fun=fun, strings.as.factors=strings.as.factors), list(...))
+  ch = chunk(ids, n.chunks = njobs, shuffle = FALSE)
+  more.args = c(list(reg = reg, part = part, fun = fun, strings.as.factors = strings.as.factors), list(...))
   # FIXME: Magic constant 10
   # FIXME: file.dir of reg2 should point to subdir of reg$file.dir
   #        m/b provide option
   reg2 = batchMapQuick(function(reg, ii, fun, part, strings.as.factors, ...) {
     # FIXME this synchronizes the registry on the node!
-    reduceResultsExperiments(reg, ii, part=part, fun=fun,
-      block.size=ceiling(length(ii) / 10), strings.as.factors=strings.as.factors, ...)
-  }, ch, more.args=more.args)
+    reduceResultsExperiments(reg, ii, part = part, fun = fun,
+      block.size = ceiling(length(ii) / 10), strings.as.factors = strings.as.factors, ...)
+  }, ch, more.args = more.args)
 
   BatchJobs:::syncRegistry(reg2)
-  while (length(BatchJobs:::dbFindDone(reg2, negate=TRUE)) > 0L) {
+  while (length(BatchJobs:::dbFindDone(reg2, negate = TRUE)) > 0L) {
     # FIXME: what happens if jobs hit the wall time?
     #        infinite loop?
     errors = BatchJobs:::dbGetErrorMsgs(reg2, filter = TRUE, limit = 1L)
@@ -83,14 +82,14 @@ reduceResultsExperimentsParallel = function(reg, ids, part=as.character(NA), fun
     BatchJobs:::syncRegistry(reg2)
   }
 
-  res = reduceResults(reg2, fun=function(aggr, job, res) {
+  res = reduceResults(reg2, fun = function(aggr, job, res) {
     d = rbind.fill(aggr, res)
     attr(d, "prob.pars.names") = union(attr(aggr, "prob.pars.names"), attr(res, "prob.pars.names"))
     attr(d, "algo.pars.names") = union(attr(aggr, "algo.pars.names"), attr(res, "algo.pars.names"))
     return(d)
-  }, init=data.frame())
+  }, init = data.frame())
 
-  unlink(reg2$file.dir, recursive=TRUE)
+  unlink(reg2$file.dir, recursive = TRUE)
   return(addClasses(res, "ReducedResultsExperiments"))
 }
 
